==> vitamui-package-8.1.2-MVN_REPO.tar.gz: fr/gouv/vitamui/referential/server/rest/UnitController.java <==
/**
 * Copyright French Prime minister Office/SGMAP/DINSIC/Vitam Program (2019-2020)
 * and the signatories of the "VITAM - Accord du Contributeur" agreement.
 *
 * contact@programmevitam.fr
 *
 * This software is a computer program whose purpose is to implement
 * implement a digital archiving front-office system for the secure and
 * efficient high volumetry VITAM solution.
 *
 * This software is governed by the CeCILL-C license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL-C
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C license and that you accept its terms.
 */
package fr.gouv.vitamui.referential.server.rest;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonNode;
import fr.gouv.vitam.common.exception.InvalidParseOperationException;
import fr.gouv.vitam.common.exception.VitamClientException;
import fr.gouv.vitamui.common.security.SanityChecker;
import fr.gouv.vitamui.commons.api.CommonConstants;
import fr.gouv.vitamui.commons.api.ParameterChecker;
import fr.gouv.vitamui.commons.api.domain.ServicesData;
import fr.gouv.vitamui.commons.vitam.api.dto.VitamUISearchResponseDto;
import fr.gouv.vitamui.referential.common.rest.RestApi;
import fr.gouv.vitamui.referential.server.service.unit.UnitService;
import lombok.Getter;
import lombok.Setter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Optional;

@RestController
@RequestMapping(RestApi.UNITS_PATH)
@Getter
@Setter
public class UnitController {

    @Autowired
    private UnitService unitExternalService;

    @GetMapping(CommonConstants.PATH_ID)
    @Secured(ServicesData.ROLE_GET_UNITS)
    public VitamUISearchResponseDto searchById(final @PathVariable("id") String id)
        throws InvalidParseOperationException, VitamClientException {
        ParameterChecker.checkParameter("The archive unit id is mandatory : ", id);
        SanityChecker.checkSecureParameter(id);
        return unitExternalService.findUnitById(id);
    }

    @PostMapping({ RestApi.DSL_PATH, RestApi.DSL_PATH + CommonConstants.PATH_ID })
    @Secured(ServicesData.ROLE_GET_UNITS)
    public JsonNode searchByDsl(final @PathVariable Optional<String> id, final @RequestBody JsonNode dsl)
        throws VitamClientException {
        ParameterChecker.checkParameter("The dsl query is mandatory : ", dsl);
        SanityChecker.sanitizeJson(dsl);
        return unitExternalService.findUnitByDsl(id, dsl);
    }

    @PostMapping(CommonConstants.PATH_ID + CommonConstants.PATH_OBJECTS)
    @Secured(ServicesData.ROLE_GET_UNITS)
    public JsonNode findObjectMetadataById(@PathVariable final String id, @RequestBody final JsonNode dsl)
        throws VitamClientException, InvalidParseOperationException {
        ParameterChecker.checkParameter("The dsl query is mandatory : ", dsl);
        SanityChecker.checkSecureParameter(id);
        SanityChecker.sanitizeJson(dsl);
        return unitExternalService.findObjectMetadataById(id, dsl);
    }

    @Secured(ServicesData.ROLE_GET_FILLING_PLAN_ACCESS)
    @GetMapping(RestApi.FILING_PLAN_PATH)
    public VitamUISearchResponseDto getFilingAndHoldingUnits() throws VitamClientException, JsonProcessingException {
        return unitExternalService.getFilingAndHoldingUnits();
    }
}

==> vitamui-package-9.0.0-MVN_REPO.tar.gz: fr/gouv/vitamui/referential/server/rest/UnitController.java <==
/**
 * Copyright French Prime minister Office/SGMAP/DINSIC/Vitam Program (2019-2020)
 * and the signatories of the "VITAM - Accord du Contributeur" agreement.
 *
 * contact@programmevitam.fr
 *
 * This software is a computer program whose purpose is to implement
 * implement a digital archiving front-office system for the secure and
 * efficient high volumetry VITAM solution.
 *
 * This software is governed by the CeCILL-C license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL-C
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C license and that you accept its terms.
 */
package fr.gouv.vitamui.referential.server.rest;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonNode;
import fr.gouv.vitam.common.exception.InvalidParseOperationException;
import fr.gouv.vitam.common.exception.VitamClientException;
import fr.gouv.vitamui.common.security.SanityChecker;
import fr.gouv.vitamui.commons.api.CommonConstants;
import fr.gouv.vitamui.commons.api.ParameterChecker;
import fr.gouv.vitamui.commons.api.domain.ServicesData;
import fr.gouv.vitamui.commons.vitam.api.dto.VitamUISearchResponseDto;
import fr.gouv.vitamui.referential.common.rest.RestApi;
import fr.gouv.vitamui.referential.server.service.unit.UnitService;
import lombok.Getter;
import lombok.Setter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.annotation.Secured;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Optional;

@RestController
@RequestMapping(RestApi.UNITS_PATH)
@Getter
@Setter
public class UnitController {

    @Autowired
    private UnitService unitService;

    @GetMapping(CommonConstants.PATH_ID)
    @Secured(ServicesData.ROLE_GET_UNITS)
    public VitamUISearchResponseDto searchById(final @PathVariable("id") String id)
        throws InvalidParseOperationException, VitamClientException {
        ParameterChecker.checkParameter("The archive unit id is mandatory : ", id);
        SanityChecker.checkSecureParameter(id);
        return unitService.findUnitById(id);
    }

    @PostMapping({ RestApi.DSL_PATH, RestApi.DSL_PATH + CommonConstants.PATH_ID })
    @Secured(ServicesData.ROLE_GET_UNITS)
    public JsonNode searchByDsl(final @PathVariable Optional<String> id, final @RequestBody JsonNode dsl)
        throws VitamClientException {
        ParameterChecker.checkParameter("The dsl query is mandatory : ", dsl);
        SanityChecker.sanitizeJson(dsl);
        return unitService.findUnitByDsl(id, dsl);
    }

    @PostMapping(CommonConstants.PATH_ID + CommonConstants.PATH_OBJECTS)
    @Secured(ServicesData.ROLE_GET_UNITS)
    public JsonNode findObjectMetadataById(@PathVariable final String id, @RequestBody final JsonNode dsl)
        throws VitamClientException, InvalidParseOperationException {
        ParameterChecker.checkParameter("The dsl query is mandatory : ", dsl);
        SanityChecker.checkSecureParameter(id);
        SanityChecker.sanitizeJson(dsl);
        return unitService.findObjectMetadataById(id, dsl);
    }

    @Secured(ServicesData.ROLE_GET_FILLING_PLAN_ACCESS)
    @GetMapping(RestApi.FILING_PLAN_PATH)
    public VitamUISearchResponseDto getFilingAndHoldingUnits() throws VitamClientException, JsonProcessingException {
        return unitService.getFilingAndHoldingUnits();
    }
}
